### MailThunder

[![Downloads](https://static.pepy.tech/badge/je-mail-thunder)](https://pepy.tech/project/je-mail-thunder)

[![MailThunder Stable Python3.8](https://github.com/Intergration-Automation-Testing/MailThunder/actions/workflows/mail_thunder_stable_python3_8.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/MailThunder/actions/workflows/mail_thunder_stable_python3_8.yml)

[![MailThunder Stable Python3.9](https://github.com/Intergration-Automation-Testing/MailThunder/actions/workflows/mail_thunder_stable_python3_9.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/MailThunder/actions/workflows/mail_thunder_stable_python3_9.yml)

[![MailThunder Stable Python3.10](https://github.com/Intergration-Automation-Testing/MailThunder/actions/workflows/mail_thunder_stable_python3_10.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/MailThunder/actions/workflows/mail_thunder_stable_python3_10.yml)

[![MailThunder Stable Python3.11](https://github.com/Intergration-Automation-Testing/MailThunder/actions/workflows/mail_thunder_stable_python3_11.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/MailThunder/actions/workflows/mail_thunder_stable_python3_11.yml)

### Documentation
TODO
---

> Project Kanban \
> https://github.com/orgs/Intergration-Automation-Testing/projects/2 

## install 

```
pip install je_mail_thunder
```

## Requires

```
python 3.8 or later
```